/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.fluss.cluster;

/** The type of server in Fluss cluster. */
public enum ServerType {
    COORDINATOR(1),
    TABLET_SERVER(2),
    UNKNOWN(-1);

    private final int typeId;

    ServerType(int typeId) {
        this.typeId = typeId;
    }

    /** Get the ServerType from its typeId. */
    public static ServerType fromTypeId(int typeId) {
        if (typeId == COORDINATOR.typeId) {
            return COORDINATOR;
        } else if (typeId == TABLET_SERVER.typeId) {
            return TABLET_SERVER;
        } else {
            return UNKNOWN;
        }
    }

    /** Get the typeId of this ServerType. */
    public int toTypeId() {
        return typeId;
    }
}
